﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Diagnostics;

namespace emanual.Wpf.Apps
{
	// 商品名の検証クラス
	internal class ProductNameValidationRule : ValidationRule
	{
		public override ValidationResult Validate(object value, System.Globalization.CultureInfo cultureInfo)
		{
			var productName = value as string;
			productName = productName.Trim();

			if (productName.Length < 1)
				return new ValidationResult(false, "商品名に入力してください。");

			return ValidationResult.ValidResult;
		}
	} // end of ProductNameValidationRule class

	//***********************************************************************************************
	// 価格の検証クラス
	internal class PriceValidationRule : ValidationRule
	{
		public override ValidationResult Validate(object value, System.Globalization.CultureInfo cultureInfo)
		{
			int price;
			string s = value as string;

			if (Int32.TryParse(s, out price) == false)
				return new ValidationResult(false, "価格は数値を指定してください。");

			if ((price < 1) || (price > 1000))
				return new ValidationResult(false, "価格は 1,000 円以下でなければなりません。");

			return ValidationResult.ValidResult;
		}
	} // end of ProductNameValidationRule class

	//***********************************************************************************************
	// 数量の検証クラス
	internal class QuantityValidationRule : ValidationRule
	{
		public override ValidationResult Validate(object value, System.Globalization.CultureInfo cultureInfo)
		{
			int unit;
			string s = value as string;

			if (Int32.TryParse(s, out unit) == false)
				return new ValidationResult(false, "個数は数値を指定してください。");

			if ((unit < 1) || (unit > 100))
				return new ValidationResult(false, "個数は 100 個以下でなければなりません。");

			return ValidationResult.ValidResult;
		}
	} // end of QuantityValidationRule class}
} // end of emanual.Wpf.Apps namespace